@@ -56,8 +56,8 @@ pip install --quiet --disable-pip-version-check -r "${source_dir}"/test_requirem
 pip install --quiet --disable-pip-version-check -e "${source_dir}"
 pip check > /dev/null
 diff -U0 \
-    <(sed -e '/#.*/d' -e '/^$/d' "${source_dir}"/test_requirements.txt | sort -f) \
-    <(pip freeze | fgrep -v git_big_picture | sort -f)
+    <(sed -e '/#.*/d' -e '/^$/d' "${source_dir}"/test_requirements.txt | sed 's,-,_,g' | sort -f) \
+    <(pip freeze | fgrep -v git_big_picture | sed 's,-,_,g' | sort -f)
 sed "s,\./,${source_dir}/,g" "${source_dir}"/.coveragerc > .coveragerc
 cp "${source_dir}"/.cramrc .
 cat <<SITECUSTOMIZE_PY_EOF > "$(ls -1d ${venv}/lib/python*)"/site-packages/sitecustomize.py
@@ -73,7 +73,7 @@ SITECUSTOMIZE_PY_EOF
 exit_code=0
 coverage erase
 
-coverage run ${venv}/bin/pytest "${source_dir}"/test.py \
+coverage run ${venv}/bin/pytest -v -s "${source_dir}"/test.py \
     || exit_code=$?
 PATH="${venv}/bin:${PATH}" COVERAGE_PROCESS_START=.coveragerc \
     coverage run ${venv}/bin/cram "${source_dir}"/test.cram \
